"""Function annotations to implement `Handlers <https://docs.symops.com/docs/handlers>`_."""

__all__ = ["hook", "reducer"]

from ._handlers import hook, reducer
